from setuptools import setup, find_packages

setup(
    name='MagInv_DNN',
    version='1.0',
    author='Zahra Ashena',
    description='Gravity and Magnetic Data DNN Inversion Toolkit',
    packages=find_packages(),
)
